@@ -1,3 +1,52 @@
+require 'dm-core'
+
+begin
+
+  require 'active_support/core_ext/class/attribute_accessors'
+  require 'active_support/core_ext/object/blank'
+  require 'active_support/ordered_hash'
+
+  class Object
+    # If receiver is callable, calls it and
+    # returns result. If not, just returns receiver
+    # itself
+    #
+    # @return [Object]
+    def try_call(*args)
+      if self.respond_to?(:call)
+        self.call(*args)
+      else
+        self
+      end
+    end
+  end
+
+rescue LoadError
+
+  require 'extlib/class'
+  require 'extlib/dictionary'
+  require 'extlib/blank'
+  require 'extlib/try_dup'
+  require 'extlib/object'
+
+  module ActiveSupport
+    OrderedHash = Dictionary
+  end
+
+end
+
+module DataMapper
+  class Property
+    def self.new(model, name, options = {}, type = nil)
+      property = super
+      property.model.auto_generate_validations(property)
+
+      # FIXME: explicit return needed for YARD to parse this properly
+      return property
+    end
+  end
+end
+
 require 'dm-validations/exceptions'
 require 'dm-validations/validation_errors'
 require 'dm-validations/contextual_validators'
@@ -21,7 +70,8 @@ require 'dm-validations/support/context'
 require 'dm-validations/support/object'
 
 module DataMapper
-  module Validate
+  module Validations
+
     Model.append_inclusions self
 
     extend Chainable
@@ -50,15 +100,15 @@ module DataMapper
     end
 
     chainable do
-      def save_self(*)
-        return false unless validation_context_stack.empty? || valid?(current_validation_context)
-        super
+      def update(attributes = {}, context = default_validation_context)
+        validation_context(context) { super(attributes) }
       end
     end
 
     chainable do
-      def update(attributes = {}, context = default_validation_context)
-        validation_context(context) { super(attributes) }
+      def save_self(*)
+        return false unless !dirty_self? || validation_context_stack.empty? || valid?(current_validation_context)
+        super
       end
     end
 
@@ -89,33 +139,8 @@ module DataMapper
       klass.validators.execute(context, self)
     end
 
-    # Begin a recursive walk of the model checking validity
-    #
-    def all_valid?(context = :default)
-      recursive_valid?(self, context, true)
-    end
-
-    # Do recursive validity checking
-    #
-    def recursive_valid?(target, context, state)
-      valid = state
-      target.instance_variables.each do |ivar|
-        ivar_value = target.instance_variable_get(ivar)
-        if ivar_value.validatable?
-          valid = valid && recursive_valid?(ivar_value, context, valid)
-        elsif ivar_value.respond_to?(:each)
-          ivar_value.each do |item|
-            if item.validatable?
-              valid = valid && recursive_valid?(item, context, valid)
-            end
-          end
-        end
-      end
-      return valid && target.valid?
-    end
-
     def validation_property_value(name)
-      respond_to?(name, true) ? send(name) : nil
+      __send__(name) if respond_to?(name, true)
     end
 
     # Get the corresponding Resource property, if it exists.
@@ -128,48 +153,45 @@ module DataMapper
       end
     end
 
-    def validation_association_keys(name)
-      if model.relationships.has_key?(name)
-        result = []
-        relation = model.relationships[name]
-        relation.child_key.each do |key|
-          result << key.name
-        end
-        return result
-      end
-      nil
-    end
-
     module ClassMethods
-      include DataMapper::Validate::ValidatesPresent
-      include DataMapper::Validate::ValidatesAbsent
-      include DataMapper::Validate::ValidatesIsConfirmed
-      include DataMapper::Validate::ValidatesIsPrimitive
-      include DataMapper::Validate::ValidatesIsAccepted
-      include DataMapper::Validate::ValidatesFormat
-      include DataMapper::Validate::ValidatesLength
-      include DataMapper::Validate::ValidatesWithin
-      include DataMapper::Validate::ValidatesIsNumber
-      include DataMapper::Validate::ValidatesWithMethod
-      include DataMapper::Validate::ValidatesWithBlock
-      include DataMapper::Validate::ValidatesIsUnique
-      include DataMapper::Validate::AutoValidate
+      include DataMapper::Validations::ValidatesPresence
+      include DataMapper::Validations::ValidatesAbsence
+      include DataMapper::Validations::ValidatesConfirmation
+      include DataMapper::Validations::ValidatesPrimitiveType
+      include DataMapper::Validations::ValidatesAcceptance
+      include DataMapper::Validations::ValidatesFormat
+      include DataMapper::Validations::ValidatesLength
+      include DataMapper::Validations::ValidatesWithin
+      include DataMapper::Validations::ValidatesNumericality
+      include DataMapper::Validations::ValidatesWithMethod
+      include DataMapper::Validations::ValidatesWithBlock
+      include DataMapper::Validations::ValidatesUniqueness
+      include DataMapper::Validations::AutoValidations
 
       # Return the set of contextual validators or create a new one
       #
       def validators
-        @validations ||= ContextualValidators.new
+        @validators ||= ContextualValidators.new
       end
 
+      def inherited(base)
+        super
+        validators.contexts.each do |context, validators|
+          base.validators.context(context).concat(validators)
+        end
+      end
+
+      private
+
       # Clean up the argument list and return a opts hash, including the
       # merging of any default opts. Set the context to default if none is
       # provided. Also allow :context to be aliased to :on, :when & group
       #
       def opts_from_validator_args(args, defaults = nil)
-        opts = args.last.kind_of?(Hash) ? args.pop : {}
+        opts = args.last.kind_of?(Hash) ? args.pop.dup : {}
         context = opts.delete(:group) || opts.delete(:on) || opts.delete(:when) || opts.delete(:context) || :default
-        opts[:context] = context
-        opts.merge!(defaults) unless defaults.nil?
+        opts[:context] = Array(context)
+        opts.update(defaults) unless defaults.nil?
         opts
       end
 
@@ -178,21 +200,12 @@ module DataMapper
       # if it does not already exist
       #
       def create_context_instance_methods(context)
-        name = "valid_for_#{context.to_s}?"           # valid_for_signup?
-        if !instance_methods.include?(name)
+        name = "valid_for_#{context.to_s}?"
+        unless respond_to?(:resource_method_defined) ? resource_method_defined?(name) : instance_methods.include?(name)
           class_eval <<-RUBY, __FILE__, __LINE__ + 1
-            def #{name}                               # def valid_for_signup?
-              valid?(#{context.to_sym.inspect})       #   valid?(:signup)
-            end                                       # end
-          RUBY
-        end
-
-        all = "all_valid_for_#{context.to_s}?"        # all_valid_for_signup?
-        if !instance_methods.include?(all)
-          class_eval <<-RUBY, __FILE__, __LINE__ + 1
-            def #{all}                                # def all_valid_for_signup?
-              all_valid?(#{context.to_sym.inspect})   #   all_valid?(:signup)
-            end                                       # end
+            def #{name}                          # def valid_for_signup?
+              valid?(#{context.to_sym.inspect})  #   valid?(:signup)
+            end                                  # end
           RUBY
         end
       end
@@ -205,28 +218,27 @@ module DataMapper
       #
       # @param [Array<Symbol>] fields
       #    Fields given to validation macro, example:
-      #    [:first_name, :last_name] in validates_present :first_name, :last_name
+      #    [:first_name, :last_name] in validates_presence_of :first_name, :last_name
       #
       # @param [Class] klazz
-      #    Validator class, example: DataMapper::Validate::LengthValidator
-      def add_validator_to_context(opts, fields, klazz)
+      #    Validator class, example: DataMapper::Validations::LengthValidator
+      def add_validator_to_context(opts, fields, validator_class)
         fields.each do |field|
-          validator = klazz.new(field, opts.dup)
-          if opts[:context].is_a?(Symbol)
-            unless validators.context(opts[:context]).include?(validator)
-              validators.context(opts[:context]) << validator
-              create_context_instance_methods(opts[:context])
-            end
-          elsif opts[:context].is_a?(Array)
-            opts[:context].each do |c|
-              unless validators.context(c).include?(validator)
-                validators.context(c) << validator
-                create_context_instance_methods(c)
-              end
-            end
+          validator = validator_class.new(field, opts.dup)
+
+          opts[:context].each do |context|
+            validator_contexts = validators.context(context)
+            next if validator_contexts.include?(validator)
+            validator_contexts << validator
+            create_context_instance_methods(context)
           end
         end
       end
     end # module ClassMethods
-  end # module Validate
+  end # module Validations
+
+  # Provide a const alias for backward compatibility with plugins
+  # This is scheduled to go away though, definitely before 1.0
+  Validate = Validations
+
 end # module DataMapper
