@@ -1,11 +1,11 @@
 module DataMapper
   class Property
     # for options_with_message
-    OPTIONS << :message << :messages << :set
+    accept_options :message, :messages, :set, :validates, :auto_validation, :format
   end
 
-  module Validate
-    module AutoValidate
+  module Validations
+    module AutoValidations
       @disable_auto_validations = false
 
       # adds message for validator
@@ -36,11 +36,10 @@ module DataMapper
       # Auto-generate validations for a given property. This will only occur
       # if the option :auto_validation is either true or left undefined.
       #
-      # @details [Triggers]
       #   Triggers that generate validator creation
       #
-      #   :nullable => false
-      #       Setting the option :nullable to false causes a
+      #   :required => true
+      #       Setting the option :required to true causes a
       #       validates_presence_of validator to be automatically created on
       #       the property
       #
@@ -59,12 +58,12 @@ module DataMapper
       #       validator to be automatically created on the property
       #
       #   Integer type
-      #       Using a Integer type causes a validates_is_number
+      #       Using a Integer type causes a validates_numericality_of
       #       validator to be created for the property.  integer_only
       #       is set to true
       #
       #   BigDecimal or Float type
-      #       Using a Integer type causes a validates_is_number
+      #       Using a Integer type causes a validates_numericality_of
       #       validator to be created for the property.  integer_only
       #       is set to false, and precision/scale match the property
       #
@@ -111,8 +110,8 @@ module DataMapper
       def disabled_auto_validations?
         @disable_auto_validations || false
       end
-      alias auto_validations_disabled? disabled_auto_validations?
 
+      alias_method :auto_validations_disabled?, :disabled_auto_validations?
 
       # Checks whether or not property should be auto validated.
       # It is the case for properties with :auto_validation option
@@ -125,20 +124,20 @@ module DataMapper
       end
 
       def infer_presence_validation_for(property, options)
-        return if allow_nil?(property)
+        return if skip_presence_validation?(property)
 
-        validates_present property.name, options_with_message(options, property, :presence)
+        validates_presence_of property.name, options_with_message(options, property, :presence)
       end
 
       def infer_length_validation_for(property, options)
-        return unless [ String, DataMapper::Types::Text ].include?(property.type)
+        return unless [ DataMapper::Property::String, DataMapper::Property::Text ].include?(property.class)
 
-        case length = property.options.fetch(:length, DataMapper::Property::DEFAULT_LENGTH)
+        case length = property.options.fetch(:length, DataMapper::Property::String::DEFAULT_LENGTH)
           when Range then options[:within]  = length
           else            options[:maximum] = length
         end
 
-        validates_length property.name, options_with_message(options, property, :length)
+        validates_length_of property.name, options_with_message(options, property, :length)
       end
 
       def infer_format_validation_for(property, options)
@@ -146,7 +145,7 @@ module DataMapper
 
         options[:with] = property.options[:format]
 
-        validates_format property.name, options_with_message(options, property, :format)
+        validates_format_of property.name, options_with_message(options, property, :format)
       end
 
       def infer_uniqueness_validation_for(property, options)
@@ -156,9 +155,9 @@ module DataMapper
           when Array, Symbol
             options[:scope] = Array(value)
 
-            validates_is_unique property.name, options_with_message(options, property, :is_unique)
+            validates_uniqueness_of property.name, options_with_message(options, property, :is_unique)
           when TrueClass
-            validates_is_unique property.name, options_with_message(options, property, :is_unique)
+            validates_uniqueness_of property.name, options_with_message(options, property, :is_unique)
         end
       end
 
@@ -171,31 +170,35 @@ module DataMapper
       end
 
       def infer_type_validation_for(property, options)
-        options[:gte] = property.min if property.min
-        options[:lte] = property.max if property.max
+        return if property.custom?
 
-        if Integer == property.type
+        if property.kind_of?(Property::Numeric)
+          options[:gte] = property.min if property.min
+          options[:lte] = property.max if property.max
+        end
+
+        if Integer == property.primitive
           options[:integer_only] = true
 
-          validates_is_number property.name, options_with_message(options, property, :is_number)
-        elsif BigDecimal == property.type || Float == property.type
+          validates_numericality_of property.name, options_with_message(options, property, :is_number)
+        elsif BigDecimal == property.primitive || Float == property.primitive
           options[:precision] = property.precision
           options[:scale]     = property.scale
 
-          validates_is_number property.name, options_with_message(options, property, :is_number)
-        elsif !property.custom?
+          validates_numericality_of property.name, options_with_message(options, property, :is_number)
+        else
           # We only need this in the case we don't already
           # have a numeric validator, because otherwise
           # it will cause duplicate validation errors
-          validates_is_primitive property.name, options_with_message(options, property, :is_primitive)
+          validates_primitive_type_of property.name, options_with_message(options, property, :is_primitive)
         end
       end
 
       private
 
-      def allow_nil?(property)
-        property.nullable? || property.serial?
+      def skip_presence_validation?(property)
+        property.allow_blank? || property.serial?
       end
-    end # module AutoValidate
-  end # module Validate
+    end # module AutoValidations
+  end # module Validations
 end # module DataMapper
