@@ -1,7 +1,7 @@
-require "forwardable"
+require 'forwardable'
 
 module DataMapper
-  module Validate
+  module Validations
 
     ##
     #
@@ -27,18 +27,11 @@ module DataMapper
       # API
       #
 
-      def dump
-        contexts.each_pair do |key, context|
-          puts "Key=#{key} Context: #{context}"
-        end
-      end
-      alias_method :inspect, :dump
-
       # Return an array of validators for a named context
       #
       # @param  [String]
       #   Context name for which return validators
-      # @return [Array<DataMapper::Validate::GenericValidator>]
+      # @return [Array<DataMapper::Validations::GenericValidator>]
       #   An array of validators
       def context(name)
         contexts[name] ||= []
@@ -59,20 +52,13 @@ module DataMapper
       # @return [Boolean]
       #   true if all are valid, otherwise false
       def execute(named_context, target)
-        raise(ArgumentError, "validation context #{named_context} doesn't seem to be defined. Known contexts are #{contexts.keys.inspect}") if !named_context || (contexts.length > 0 && !contexts[named_context])
         target.errors.clear!
-        result = true
-        # note that all? and any? stop iteration on first negative or positive result,
-        # so we really have to use each here to make sure all validators are
-        # executed
-        context(named_context).select { |validator| validator.execute?(target) }.each do |validator|
-          result = false unless validator.call(target)
-        end
 
-
-        result
+        context(named_context).map do |validator|
+          validator.execute?(target) ? validator.call(target) : true
+        end.all?
       end
 
     end # module ContextualValidators
-  end # module Validate
+  end # module Validations
 end # module DataMapper
