@@ -1,7 +1,5 @@
-require 'extlib/dictionary'
-
 module DataMapper
-  module Validate
+  module Validations
 
     ##
     #
@@ -37,10 +35,12 @@ module DataMapper
       }
 
       # Holds a hash with all the default error messages that can be replaced by your own copy or localizations.
-      cattr_writer :default_error_messages
+      def self.default_error_messages=(default_error_messages)
+        @@default_error_messages = default_error_messages
+      end
 
       def self.default_error_message(key, field, *values)
-        field = Extlib::Inflection.humanize(field)
+        field = DataMapper::Inflector.humanize(field)
         @@default_error_messages[key] % [field, *values].flatten
       end
 
@@ -48,7 +48,7 @@ module DataMapper
 
       def initialize(resource)
         @resource = resource
-        @errors   = Dictionary.new
+        @errors   = ActiveSupport::OrderedHash.new { |h,k| h[k] = [] }
       end
 
       # Clear existing validation errors.
@@ -84,21 +84,10 @@ module DataMapper
         end
       end
 
-      # Return validation errors for a particular field name or an empty array
-      #
-      # This method is a necessary requirement for active_model compatibility.
-      #
-      # @param [Symbol] field_name the name of the field you want an error for
-      # @return [Array<Array<String>>]
-      #   array of validation errors or empty array, if there are no errors on given field
-      def [](field_name)
-        errors[field_name] ||= []
-      end
-
       # Return validation errors for a particular field_name.
       #
       # @param [Symbol] field_name the name of the field you want an error for
-      # @return [Array<DataMapper::Validate::Error>]
+      # @return [Array<DataMapper::Validations::Error>]
       #   array of validation errors or empty array, if there are no errors on given field
       def on(field_name)
         errors_for_field = errors[field_name]
@@ -113,18 +102,24 @@ module DataMapper
       end
 
       def empty?
-        @errors.empty?
+        @errors.all? { |property_name, errors| errors.empty? }
       end
 
       def method_missing(meth, *args, &block)
         errors.send(meth, *args, &block)
       end
 
+      def [](property_name)
+        if property_errors = errors[property_name.to_sym]
+          property_errors
+        end
+      end
+
       private
       def errors
         @errors
       end
 
     end # class ValidationErrors
-  end # module Validate
+  end # module Validations
 end # module DataMapper
