@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 module DataMapper
-  module Validate
+  module Validations
     module Fixtures
       class BasketballPlayer
         #
@@ -27,11 +27,8 @@ module DataMapper
         #
 
         # precision and scale need to be defined for length to be validated
-        validates_is_number :height, :weight, :precision => 10
+        validates_numericality_of :height, :weight, :precision => 10
       end
-      BasketballPlayer.auto_migrate!
-
-
     end # Fixtures
-  end # Validate
+  end # Validations
 end # DataMapper
