@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 module DataMapper
-  module Validate
+  module Validations
     module Fixtures
       class BillOfLading
         #
@@ -27,16 +27,16 @@ module DataMapper
         #
 
         # this is a trivial example
-        validates_format :doc_no, :with => lambda { |code|
+        validates_format_of :doc_no, :with => lambda { |code|
           code =~ /\AA\d{4}\z/ || code =~ /\A[B-Z]\d{6}X12\z/
         }
 
-        validates_format :email, :as => :email_address
-        validates_format :url, :as => :url, :allow_nil => false
+        validates_format_of :email, :as => :email_address
+        validates_format_of :url, :as => :url, :allow_nil => false, :allow_blank => false
 
-        validates_format :username, :with => /[a-z]/, :message => 'Username must have at least one letter', :allow_nil => true
-        validates_format :code,     :with => /\d{5,6}/, :message => 'Code format is invalid'
+        validates_format_of :username, :with => /[a-z]/, :message => 'Username must have at least one letter', :allow_nil => true
+        validates_format_of :code,     :with => /\d{5,6}/, :message => 'Code format is invalid'
       end
     end # Fixtures
-  end # Validate
+  end # Validations
 end # DataMapper
