@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 require 'spec_helper'
 
-describe DataMapper::Validate::ValidationErrors do
+describe 'DataMapper::Validations::ValidationErrors' do
   before :all do
-    @model = DataMapper::Validate::ValidationErrors.new(Object.new)
+    @model = DataMapper::Validations::ValidationErrors.new(Object.new)
   end
 
   describe "after first error being added" do
